@@ -6,11 +6,11 @@ use warnings;
 use POSIX qw(INT_MAX);
 use List::MoreUtils qw(none);
 use Carp qw(croak);
-use Any::Moose;
-use Any::Moose '::Util::TypeConstraints';
+use Moose;
+use Moose::Util::TypeConstraints;
 use namespace::autoclean;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 require XSLoader;
 XSLoader::load('Data::Password::passwdqc', $VERSION);
@@ -237,7 +237,7 @@ a common substring spelled backwards.
 
 Defaults to 47.
 
-The size of randomly-generated passphrases in bits (26 to 81), or 0 to
+The size of randomly-generated passphrases in bits (24 to 85), or 0 to
 disable this feature.
 
 =back
